import { View, Image, Text } from "@tarojs/components";
import { transferImage } from '@/utils/tools'
import dayjs from 'dayjs'
import copyImg from '../../assets/copy.png'
import closeImg from '../../assets/close.png'

import './index.scss'

export default function RaiseCard(props) {
  const {
    buildingName,
    termName,
    blockName,
    unitName,
    roomName,
    price,
    houseLockingStatus,
    apartmentName,
    mineLocked,
    createDate,
    buildingArea,
    insideArea,
    payStatus,
    code,
    buildingImgList = [],
  } = props.summary || {}

  const title = `${buildingName || ''} ${termName || ''} ${blockName || ''} ${unitName || ''} ${roomName || '　'}`
  const thumb = (buildingImgList || []).length
  const showDT = dayjs(createDate).format('YYYY/MM/DD')
  const wanY = Number(price)


  const copyData = (e) => {
    e.stopPropagation()
    Taro.setClipboardData({
      data: code,
      onSuccess: (() => { }),
    })
  }

  const handleCancel = () => {
    if (props.onCancel) {
      props.onCancel(props.summary)
    }
  }
  return (
    <View className="housecard" style={props.style} >
      <View className="head" onClick={props.handleCard}>
        {thumb ? <Image className="thumb" src={transferImage((buildingImgList)[0].url)} mode="aspectFit" /> :
          <Text style="font-size:26rpx;color:#666">暂无户型图</Text>
        }
      </View>
      <View className="body">
        {props.type == 'raiseMoney' && <Image src={closeImg} onClick={handleCancel} className="close-img"></Image>}
        <View onClick={props.handleCard}>
          {!props.type && <View className={payStatus == 'paid' ? 'raised badge' : payStatus == 'unpaid' ? 'unraise badge' : 'badge'}>{payStatus == 'paid' ? '已缴费' : payStatus == 'unpaid' ? '未缴费' : '已退费'}</View>}
          {(props.type == 'raiseProfile' || props.type == 'houseResource') && houseLockingStatus == 'locked' && <View style="color:#FF3C3C" className='raised badge'>{mineLocked ? '已锁给我' : ''}</View>}
          {props.type == 'raiseProfile' || props.type == 'raiseMoney' && <View style={props.type == 'raiseMoney' ? 'color:#BB9C79;font-size:30rpx' : 'color:#BB9C79;font-size:30rpx;margin-top:-20rpx'}>{apartmentName || '　'}</View>}
          {props.type == 'raiseMoney' && <View className="red-price">现价{Number(price) + 0}万</View>}
          {props.type == 'houseResource' && <View style="color:#BB9C79;font-size:28rpx;margin:-40rpx 0 26rpx 0">{houseLockingStatus == 'locked' ? '已锁定' : '未锁定'}</View>}
          <View className="title">{title}</View>
          {!props.type && <View className="meta">{showDT}</View>}
          {props.type == 'raiseProfile' && <View className="price">现价<Text className="red">{Number(price) + 0}</Text>万</View>}
          {props.type == 'raiseProfile' || props.type == 'raiseMoney' && buildingArea && <View className="area">建筑面积约<Text className="red">{buildingArea}m²</Text></View>}
          {props.type == 'raiseProfile' || props.type == 'raiseMoney' && insideArea && <View className="area">使用面积约<Text className="red">{insideArea}m²</Text></View>}
        </View>
        {props.type == 'houseResource' && <View className="house-code" style="margin-top:26rpx">房源编号：{code}
          <Image src={copyImg} className="copy-img" onClick={copyData}></Image>
        </View>}
      </View>

    </View>
  )
}
