import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView } from '@tarojs/components'

import './index.scss'
import Blank from '../../components/Blank'
import HouseGrid from '../../components/HouseGrid'

export default class extends Component {
  config = {
    navigationBarTitleText: '添加其他房源',
  }

  state = {
    dataType: 1, // maybe need change  1 预选, 2 认筹
    houseList: [ { name: '1期1栋1单元1楼101户' } ],
    chooseList: [ { name: '1期1栋1单元1楼101户' }, { name: '1期1栋1单元1楼102户' } ], // 已经选择的房源列表
    collapsed: true, // 已选列表默认关闭, true 关闭, false 开启 
  }

  componentWillMount () {}

  changeShowData = (dataType) => {
    // 此处需要按照 dataType 去切换数据
    // 切换成功之后
    this.setState({ dataType })
  }

  // 添加到选择列表
  // 注意, 不是确认选择
  add2Cart = (room) => {

  }

  // 确认选择
  handleSubmit = () => {

  }

  // 取消选择
  subChooseList = (house) => {
    Taro.showModal({
      title: '取消选择',
      content: `确认取消 ${house.name} ?`,
      success: (res) => {
        if (res.confirm) {
          // TODO: 取消房源选择
        }
      }
    })
  }

  // 是否展开已选列表
  trigCartPannel = () => {
    const { collapsed } = this.state;
    this.setState({ collapsed: !collapsed })
  }

  renderHead() {
    const { dataType, houseList } = this.state
    const hasData = houseList && houseList.length

    return (
      <View className="head">
        <View className="tips">仅显示符合认筹条件的房源。点击房源卡片查看房源详情，不要在房源详情页做操作。请在当前页面选择提交认筹。</View>
        {
          hasData && (
            <View className="actions">
              <View className={`action ${dataType === 1 ? 'active' : ''}`} onClick={() => this.changeShowData(1)}>预选热度图</View>
              <View className={`action ${dataType === 2 ? 'active' : ''}`} onClick={() => this.changeShowData(2)}>认筹热度图</View>
            </View>
          )
        }
      </View>
    );
  }

  renderHouses() {
    const { houseList } = this.state
    const hasData = houseList && houseList.length

    return hasData && (
      <ScrollView className="body" scrollY>
      {
        houseList.map((item) => {
          return <HouseGrid key={item.unitId} dataset={item} onRoomClick={this.handleRoomClick} onActionClick={this.add2Cart} />
        })
      }
      </ScrollView>
    )
  }

  renderAction() {
    const { chooseList, collapsed, houseList } = this.state;
    const title = collapsed ? `已选择: ${chooseList[0].name} 等 ${chooseList.length} 个房源` : '已选列表'
    const opened = collapsed ? 'off' : 'on'
    const nodata = houseList && houseList.length ? '' : 'nodata'
    const btnText = chooseList && chooseList.length ? '确认以上选择' : '未选择房源'
    const choosed = chooseList && chooseList.length

    return (
      <View className="footer">
      {
        choosed && (
          <View className="shoping-cart collapse">
            <View className={`title ${opened}`} onClick={this.trigCartPannel}>
              <Text>{title}</Text>
              {collapsed?<Text className="at-icon at-icon-chevron-up"></Text> :<Text className="at-icon at-icon-chevron-down"></Text> }           
            </View>

            <View className={`choose-list ${opened}`}>
              {chooseList.map((house, index) => {
                return (
                  <View key={`cart-item-${index}`} className="choose-item" onClick={() => this.subChooseList(house)}>
                    <View className="choose-item-body">{house.name}</View>
                    <View className="choose-item-action">
                      <Text className="at-icon at-icon-subtract-circle"></Text>
                    </View>
                  </View>
                )
              })}
            </View>          
          </View>
        )
      }
        <Button className={`btn ${nodata}`} onClick={this.handleSubmit}>{btnText}</Button>
      </View>
    )
  }

  renderBlank() {
    const { houseList } = this.state

    return !(houseList && houseList.length) && (
      <Blank tips="暂无符合条件的房源" />
    )
  }

  render() {
    return (
      <View className="house-cart">
        {this.renderHead()}
        {this.renderBlank()}
        {this.renderHouses()}
        {this.renderAction()}
      </View>
    )
  }
}