import Taro, { Component } from '@tarojs/taro'
import { View, Block, RichText } from '@tarojs/components'
import './index.scss'
import RaiseCard from '../../components/RaiseCard'
import Statement from '../../components/Statement'
import ConsultantItem from '../../components/ConsultantItem/index'
import ready from '@/utils/ready'
import { connect } from '@tarojs/redux'
import * as houseActions from '@/actions/house'
import NextStep from './NextStep'
import { fetch, apis } from '@/utils/request'
import Captcha from './Captcha'
import { raiseOrder, cancelOrder } from '@/services/project'

const getRaiseProfile = ({ raiseId, salesBatchId, personId }) => {
  const queryString = [
    `${raiseId ? 'raiseId=' + raiseId : ''}`,
    `${salesBatchId ? 'salesBatchId=' + salesBatchId : ''}`,
    `${personId ? 'personId=' + personId : ''}`,
  ].filter(Boolean).join('&')

  return fetch({ url: `${apis.API_RAISE_PROFILE}?${queryString}` })
}

const saveRaiseRecord = (record, raise) => {
  const data = {
    ...record,
    raiseId: raise.raiseId,
    orgId: raise.orgId,
    salesBatchId: raise.salesBatchId,
    buildingId: raise.buildingId,
  }

  return fetch({ url: `${apis.API_SAVE_RAISE_RECORD}`, method: 'POST', data })

}

@connect(({ user, house }) => ({ ...user, house }), { ...houseActions })
export default class raiseMoney extends Component {
  config = {
    navigationBarTitleText: '认筹确认'
  }
  state = {
    current: 2,
    inputName: '',
    raiseProfile: undefined,
    record: {},
  }

  // 此页面不支持分享，以及二维码
  componentWillMount() {
    ready.queue(() => {
      const {
        salesBatchId,   // 批次, 备用
        houseId,        // 房源号, 从房源详情进入的
        raiseRecordId,  // 认筹单ID, // 从认筹列表进入
      } = this.$router.params

      if (houseId) {
        this.loadHouseInfo(houseId, salesBatchId)
      }

      if (raiseRecordId) {
        this.loadRaiseRecord(raiseRecordId)
      }

      if (!houseId && !raiseRecordId) {
        Taro.showToast({
          title: '错误, 请返回上一步',
          icon: 'none',
        })
        return;
      }

      if (this.$router.params.type == 'pay') {
        this.setState({ current: 3 })
      }
    })
  }

  loadHouseInfo = (houseId, salesBatchId) => {
    const { personId } = this.props.userInfo.person

    // 请求认筹信息
    getRaiseProfile({ salesBatchId, personId }).then(res => {
      this.setState({ raiseProfile: res, record: res.record || {} })
    })
  }

  loadRaiseRecord = (raiseRecordId) => {

  }

  handleCancel = (house) => {
    Taro.showModal({
      title: '提示',
      content: '确认取消选择该房源?',
      success: (res) => {
        if (res.confirm) {
          this.props.dispatchSubCart(house)
        }
      }
    })
  }

  renderTop() {
    const tabList = [
      { title: '确认房源', value: 0 },
      { title: '阅读协议', value: 1 },
      { title: '填写资料', value: 2 },
      { title: '缴纳定金', value: 3 },
      { title: '认筹结果', value: 4 },
    ]
    const { current } = this.state

    return (
      <View className="top-con">
        {tabList.map((item, index) => (
          <View className="flex" key={index + 'top'} style={current == item.value ? 'color:#333;font-weight:700' : ''}>
            {item.title}
            {item.value != 4 &&
              <View className="flex" style="margin:0 12rpx 0 4rpx">
                <View className='right-icon'></View>
                <View className='right-icon icon2'></View>
                <View className='right-icon icon3'></View>
              </View>
            }

          </View>
        ))
        }
      </View>
    )
  }
  renderHouse() {
    const { house: { raiseCart } } = this.props
    return (
      <ScrollView scrollY className="container">
        {
          raiseCart.map(item => (
            <View key={item.houseId} >
              <RaiseCard type="raiseMoney" summary={item} onCancel={this.handleCancel} />
            </View>
          )
          )
        }
        <View className="addhouse">从<Text style="color:#BB9C79">预选记录</Text>中添加其他房源</View>
        <View className="addhouse">从<Text style="color:#F3B82E">房源列表</Text>中添加其他房源</View>
        <Statement style="margin-top:80rpx" />
      </ScrollView>
    )
  }
  renderAgreement() {
    const { raiseProfile = {} } = this.state

    return (
      <ScrollView scrollY className="container3">
        <View className="agent-box">
          <View className="center-title">线上选房协议</View>
          <View className="rich-text">
            <RichText nodes={raiseProfile.payProtocol || ''} />
          </View>
        </View>
      </ScrollView >
    )
  }

  // 获取输入
  handleInput = (key, e) => {
    const { person } = this.props.userInfo

    this.setState({
      record: {
        ...(this.state.record || {}),
        userId: person.personId,
        [`${key}`]: e.detail.value,
      }
    })
  }

  // 获取验证码
  handleCaptcha = e => {
    const { tel } = this.state.record || {}

    if (!tel) {
      Taro.showToast({
        title: '请填写手机号',
        icon: 'none'
      })
      return;
    }
  }

  tochooseConsultant() {
    Taro.navigateTo({
      url: '/onlineSelling/pages/chooseConsultant/index'
    })
  }
  renderProfile() {
    const item = { name: '哈哈哈1', phone: '138541369741', avatar: 'http://img5.imgtn.bdimg.com/it/u=3299138037,391931528&fm=26&gp=0.jpg' }
    const { record } = this.state

    return (
      <ScrollView scrollY className="container2">
        <View className="profile-box">
          <View className="title">我的个人信息</View>
          <View style="font-size:24rpx;color:#999;line-height:60rpx">除手机号外其他信息修改后会保存到个人信息中</View>
          <View className="profile-item">
            <View className="name">
              <Text style="color:#FF3C3C;font-size:32rpx;margin-right:8rpx">*</Text>
              姓名
            </View>
            <Input className='input' placeholder-style="color:#999" value={record.userName} onInput={this.handleInput.bind(this, 'userName')} type='text' placeholder='请填写真实姓名' />
          </View>
          <View className="profile-item">
            <View className="name">
              <Text style="color:#FF3C3C;font-size:32rpx;margin-right:8rpx">*</Text>
              身份证号
            </View>
            <Input className='input' placeholder-style="color:#999" value={record.idcard} onInput={this.handleInput.bind(this, 'idcard')} type='text' placeholder='请填写身份证号' />
          </View>
          <View className="profile-item">
            <View className="name">
              <Text style="color:#FF3C3C;font-size:32rpx;margin-right:8rpx">*</Text>
              手机号
            </View>
            <Input className='input' placeholder-style="color:#999" value={record.tel} onInput={this.handleInput.bind(this, 'tel')} type='text' placeholder='请填写手机号' />
          </View>
          <View className="profile-item">
            <View className="name">
              <Text style="color:#FF3C3C;font-size:32rpx;margin-right:8rpx">*</Text>
              验证码
            </View>
            <Input className='inputCode' placeholder-style="color:#999" onInput={this.handleCaptcha} type='text' placeholder='请填写验证码' />
            <Captcha countdown={5} />
          </View>
          <View className="profile-flex" style="margin-top:20rpx">
            <View className="title">我的置业顾问信息</View>
            <View className="choose" onClick={() => this.tochooseConsultant}>选择置业顾问</View>
          </View>
          <ConsultantItem
            data={item}
            style="padding:30rpx 0;width:690rpx; border-bottom: 1px solid #dcdcdc;"
            type="raiseMoney"
            onClick={this.handleItemClick}>
          </ConsultantItem>
        </View>
      </ScrollView >
    )
  }
  renderMoney() {
    return (
      <ScrollView scrollY className="container2" style="padding:0 30rpx">
        <View className="profile-flex">
          <View className="title">认筹金额</View>
          <View className="price">1 元</View>
        </View>
        <View className="center-title">线上选房协议</View>
      </ScrollView >
    )
  }

  makeRaiseRecord = () => {
    const { record, raiseProfile } = this.state
    const { house } = this.props
    const houseList = house.raiseCart.map(x => x.houseId)

    return new Promise((resolve, reject) => {
      saveRaiseRecord({ ...record, houseList }, raiseProfile).then(() => {
        resolve()
      })
    })
  }

  makePay = () => {
    const params = {
      targetId: this.$router.params.raiseRecordId,
      targetType: 'house'
    }

    return new Promise((resolve, reject) => {
      raiseOrder(params).then(res => {

        Taro.requestPayment({
          timeStamp: String(res.timeStamp),
          nonceStr: res.nonceStr,
          package: res.package,
          signType: res.signType,
          paySign: res.sign,

          success(res) {
            // 最后
            resolve()
          },
          fail(err) {
            console.log(err, "errrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrr")

            cancelOrder(params).then(res => { })

            // 然后
            reject()
          }
        })
      })
    })

  }

  nextStep(current) {
    switch (current) {
      // 认筹确认
      case 2:
        this.makeRaiseRecord().then(() => {
          this.setState({
            current: current + 1
          })
        })
        return;

      // 缴费
      case 3:
        this.makePay().then()
        return;

      //
      default:
        this.setState({
          current: current + 1
        })

    }
  }

  upStep(current) {
    this.setState({
      current: current - 1
    })
  }

  renderBottomBtn() {
    const { current } = this.state
    return (
      <View className="bottom-btn">
        {current == 1 && <View style="font-size:24rpx;color:#999;line-height:70rpx">请仔细阅读选房协议直到结尾才能进入下一步</View>}
        {current != 4 &&
          <NextStep
            countdown={current == 1 ? 2 : 0}
            onClick={() => this.nextStep(current)}
            text={current == 3 ? '现在缴费' : '下一步'}
          />
        }
        {current != 0 && <View className="up-btn" onClick={() => this.upStep(current)}>上一步</View>}
      </View>
    )
  }

  render() {
    const { current } = this.state
    return (
      <View className="raiseMoney">
        {this.renderTop()}
        {current == 0 && this.renderHouse()}
        {current == 1 && this.renderAgreement()}
        {current == 2 && this.renderProfile()}
        {current == 3 && this.renderMoney()}
        {this.renderBottomBtn()}
      </View>
    )
  }

}
