import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView, Block } from '@tarojs/components'
import HouseCard from '../../components/HouseCard'
import RaiseCard from '../../components/RaiseCard'
import { getItemList } from '@/services/item'
import { queryPreselectionRecord, queryRaiseRecord, querySalesList, queryApartmentType } from '@/services/project'
import { connect } from '@tarojs/redux'
import ready from '@/utils/ready'
import Blank from '../../components/Blank'
import Statement from '../../components/Statement'
import { transferImage } from '@/utils/tools'
import PickerComponent from '../../components/Picker'
import './index.scss'

@connect(
  ({ user, city }) => ({ ...user, ...city })
)

export default class Records extends Component {
  config = {
    navigationBarTitleText: '选房记录'
  }

  state = {

    current: 0,
    recordList: [],
    noRecord: false,
    raiseList: [],
    noRaiseRecord: false,
    screenVisible: false,
    buildingList: [],
    buildingValue: '',
    buildingId: '',

    salesList: [],
    saleBatch: '',
    salesBatchId: '',

    apartmentList: [],
    apartmentValue: '',
    apartmentId: '',

    lockStatus: [{ value: '不限', code: '' }, { value: '未锁定', code: 'unlocked' }, { value: '已锁定', code: 'locked' }],
    lockStatusValue: '',
    houseLockingStatus: '',

    lockCustomer: [{ value: '不限', code: '' }, { value: '我自己', code: 'mine' }, { value: '其他人', code: 'other' }],
    lockCustomerValue: '',
    customerLocked: '',
  }
  componentDidShow() {
    ready.queue(() => {

      const { userInfo: { person: { personId } } } = this.props
      const params = {
        personId,
        pageNumber: 1,
        pageSize: 999,
      }
      this.getPreselection(params)
      this.getRaise(params)
      querySalesList().then(res => {
        res.unshift({ salesBatchName: '请选择', salesBatchId: '' })
        this.setState({
          salesList: res || [],

        })
      })
      this.loadBuildingList()
    })
  }
  getPreselection(params) {
    queryPreselectionRecord(params).then(res => {
      const list = res.records
      this.setState({
        recordList: list.filter(item => item.status == '1') || [],

      }, () => {
        this.setState({
          noRecord: this.state.recordList.length > 0 ? false : true
        })
      })
    })
  }
  getRaise(params) {
    queryRaiseRecord(params).then(res => {
      this.setState({
        raiseList: res.records || [],

      }, () => {
        this.setState({
          noRaiseRecord: this.state.raiseList.length > 0 ? false : true
        })
      })
    })
  }
  loadBuildingList() {
    const params = {
      pageNumber: 1,
      pageSize: 50,
      cityId: this.props.curCity.id || ''
    }
    getItemList(params).then(res => {
      res.records.unshift({ buildingName: '请选择', buildingId: '' })
      this.setState({
        buildingList: res.records,
      })
    })

  }

  CheckboxChange = (e) => {
    e.stopPropagation()
    console.log('checkbox发生change事件，携带value值为：', e)
  }

  renderPreselection() {
    const { recordList, noRecord } = this.state
    return (
      <Block>
        <ScrollView scrollY className="container">
          <CheckboxGroup onChange={this.CheckboxChange}>
            {
              noRecord ? <Blank style="margin:10vh 0 22vh 0" tips="暂无预选记录" /> :
                <View>
                  {
                    recordList.map((item) => {
                      return (
                        <Label class="checkbox" >
                          <Checkbox value={item.houseId} checked={item.checked} >
                            <View className="carditem" key={item.preselectionRecordId} >

                              <HouseCard summary={item} />
                            </View>
                          </Checkbox>
                        </Label>
                      )
                    })
                  }
                </View>
            }
          </CheckboxGroup>
          <Statement />
        </ScrollView >

        <View className="raise-box"> <View className="raise-btn">认筹房源</View></View>

      </Block>
    )
  }
  toRaiseProfile(id) {
    Taro.navigateTo({
      url: `/onlineSelling/pages/raiseProfile/index?raiseRecordId=${id}`
    })
  }
  renderRaise() {
    const { raiseList, noRaiseRecord } = this.state
    return (
      <Block>

        {
          noRaiseRecord ? <Blank style="margin:10vh 0 22vh 0" tips="暂无认筹记录" /> :
            <ScrollView scrollY>
              {
                raiseList.map(item => (
                  <View key={item.raiseRecordId} >
                    <RaiseCard handleCard={()=>this.toRaiseProfile(item.raiseRecordId)} summary={item} />
                  </View>
                )
                )
              }
            </ScrollView >
        }
        <Statement styel="margin-top:80rpx" />


      </Block>
    )
  }


  handleBuildingChange = e => {
    const { buildingList } = this.state
    this.setState({
      buildingValue: buildingList[e.detail.value].buildingName,
      buildingId: buildingList[e.detail.value].buildingId,
    })
  }
  handleSaleBatchChange = e => {
    const { salesList } = this.state
    this.setState({
      saleBatch: salesList[e.detail.value].salesBatchName,
      salesBatchId: salesList[e.detail.value].salesBatchId,

    }, () => {
      if (this.state.salesBatchId) {
        console.log('hhhhhhhhhhhhhh')
        this.loadAparamentType(this.state.salesBatchId)
      } else {
        console.log('hjjjjjjjjjjjhhhh')
        this.setState({
          apartmentList: [{ apartmentName: '请选择', apartmentId: '' }]
        })
      }
    })
  }
  loadAparamentType(salesBatchId) {
    queryApartmentType({ salesBatchId: salesBatchId }).then(res => {
      res.unshift({ apartmentName: '请选择', apartmentId: '' })
      this.setState({
        apartmentList: res || []
      })
    })
  }
  handleApartmentChange = e => {

    const { apartmentList } = this.state

    this.setState({
      apartmentValue: apartmentList[e.detail.value].apartmentName,
      apartmentId: apartmentList[e.detail.value].apartmentId,
    })

  }
  handleLockStatusChange = e => {
    const { lockStatus } = this.state
    this.setState({
      lockStatusValue: lockStatus[e.detail.value].value,
      houseLockingStatus: lockStatus[e.detail.value].code,
    })
  }
  handleCustomerChange = e => {
    const { lockCustomer } = this.state
    this.setState({
      lockCustomerValue: lockCustomer[e.detail.value].value,
      customerLocked: lockCustomer[e.detail.value].code,
    })
  }


  unlimitedBtn() {

    this.setState({
      screenVisible: false,
      buildingValue: '',
      buildingId: '',
      saleBatch: '',
      salesBatchId: '',
      apartmentValue: '',
      apartmentId: '',
      lockStatusValue: '',
      houseLockingStatus: '',
      lockCustomerValue: '',
      customerLocked: '',
    })
    const { userInfo: { person: { personId } } } = this.props
    const params = {
      personId,
      pageNumber: 1,
      pageSize: 999,
    }
    this.getPreselection(params)
    this.getRaise(params)
  }
  ScreenBtn() {
    this.setState({
      screenVisible: false
    })
    const { userInfo: { person: { personId } } } = this.props
    const { buildingId, salesBatchId, houseLockingStatus, apartmentId, customerLocked } = this.state

    if (this.state.current == '0') {

      const params = {
        personId,
        pageNumber: 1,
        pageSize: 999,
        buildingId,
        salesBatchId,
        apartmentId,
        houseLockingStatus,
        customerLocked
      }
      this.getPreselection(params)
    } else {

      const params = {
        personId,
        pageNumber: 1,
        pageSize: 999,
        buildingId,
        salesBatchId,
        houseLockingStatus,

      }
      this.getRaise(params)
    }


  }

  renderPreselectScreen() {
    const { current, buildingValue, buildingList, saleBatch, salesList, apartmentList, apartmentValue, lockCustomerValue, lockCustomer, lockStatusValue, lockStatus } = this.state

    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]

    return (

      <View className="base-con">
        <PickerComponent title="选择楼盘" selector={buildingList} keyValue={"buildingName"} currentValue={buildingValue || ''} handleChange={this.handleBuildingChange} />
        <PickerComponent title="选择销售批次" selector={salesList} keyValue={"salesBatchName"} currentValue={saleBatch || ''} handleChange={this.handleSaleBatchChange} />
        {current == '0' && <PickerComponent title="选择户型" selector={apartmentList} keyValue={"apartmentName"} currentValue={apartmentValue || ''} handleChange={this.handleApartmentChange} />}
        <PickerComponent title="锁定状态" selector={lockStatus} keyValue={"value"} currentValue={lockStatusValue || ''} handleChange={this.handleLockStatusChange} />
        {current == '0' && <PickerComponent title="锁定客户" keyValue={"value"} selector={lockCustomer} currentValue={lockCustomerValue || ''} handleChange={this.handleCustomerChange} />}

        <View className="bottom-btn">
          <View className="save" onClick={this.ScreenBtn}>
            筛选
            </View>
          <View className="cancel" onClick={this.unlimitedBtn}>
            不限
          </View>
        </View>
      </View>
    )
  }


  handleScreenClick() {


    this.setState({
      screenVisible: true
    })

  }
  handleCondition(value) {
    this.setState({
      current: value,
      buildingValue: '',
      buildingId: '',
      saleBatch: '',
      salesBatchId: '',
      apartmentValue: '',
      apartmentId: '',
      lockStatusValue: '',
      houseLockingStatus: '',
      lockCustomerValue: '',
      customerLocked: '',


    })
  }
  renderBar() {
    const { current } = this.state
    const condition = [{ title: '预选记录', value: 0 }, { title: '认筹单', value: 1 }]

    return (
      <Block>
        <View className="screen-top">
          <View className="flex">
            {condition.map(item => (
              <View key={item.value} onClick={() => this.handleCondition(item.value)} className={current == item.value ? 'top-item active' : 'top-item'}>
                {item.title}
              </View>
            ))}
          </View>
          <View onClick={this.handleScreenClick}>
            <Image style="width:50rpx;height:50rpx" src={transferImage(require('../../assets/screen.png'))}></Image>
          </View>
        </View>
        {current == 0 && this.renderPreselection()}
        {current == 1 && this.renderRaise()}
      </Block>
    )
  }
  render() {

    const { screenVisible } = this.state
    return (
      <View className="records" >
        {!screenVisible && this.renderBar()}
        {screenVisible && this.renderPreselectScreen()}

      </View >
    )
  }
}
